# import things here to make them visible to Plone.
# Note, just commenting something out here isn't enough--
# the Install.py method also should be changed,
# and the __init__ method for HelpCenter.py.

import HelpCenter

import FAQFolder, FAQ

import HowToFolder, HowTo

import TutorialFolder, Tutorial, TutorialPage

import ReferenceManualFolder, ReferenceManual, ReferenceManualSection, ReferenceManualPage

import InstructionalVideoFolder, InstructionalVideo

import LinkFolder, Link

import ErrorReferenceFolder, ErrorReference

import Glossary, Definition

import KnowledgeBase
